Description Usage Arguments Details Value References See Also Examples
An alias for qlogis as logit, and alias for plogis as inv_logis.
1 2 3 4 |
p |
vector of probabilities. |
location |
location and scale parameters. |
scale |
location and scale parameters. |
lower.tail |
logical; if TRUE (default), probabilities are P[X ≤ x], otherwise, P[X > x]. |
log.p |
logical; if TRUE, probabilities p are given as log(p). |
q |
vector of quantiles. |
If location or scale are omitted, they assume the
default values of 0 and 1 respectively.
The Logistic distribution with location = m and
scale = s has distribution function
F(x) = 1 / (1 + exp(-(x-m)/s))
and density
f(x) = 1/s exp((x-m)/s) (1 + exp((x-m)/s))^-2.
It is a long-tailed distribution with mean m and variance π^2 /3 s^2.
dlogis gives the density,
plogis gives the distribution function,
qlogis gives the quantile function, and
rlogis generates random deviates.
The length of the result is determined by n for
rlogis, and is the maximum of the lengths of the
numerical arguments for the other functions.
The numerical arguments other than n are recycled to the
length of the result. Only the first elements of the logical
arguments are used.
Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988) The New S Language. Wadsworth & Brooks/Cole.
Johnson, N. L., Kotz, S. and Balakrishnan, N. (1995) Continuous Univariate Distributions, volume 2, chapter 23. Wiley, New York.
Distributions for other standard distributions.
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.